@@ -734,7 +734,9 @@ for every column set.
 This hook will be called after a value is successfully set in the
 database. It will be called with a reference to a paramhash that
 contains C<column> and C<value> keys. If C<value> was a SQL function,
-it will now contain the actual value that was set.
+it will now contain the actual value that was set. If C<column> has
+filters on it, C<value> will be the result of going through an encode
+and decode cycle.
 
 This hook's return value is ignored.
 
@@ -1215,7 +1217,8 @@ sub load_from_hash {
         # Optimization for loading from database
         $self->{values} = $hashref;
         $self->{fetched}{$_} = 1 for keys %{$hashref};
-        $self->{raw_values} = {};
+        # copy $hashref so changing 'values' doesn't change 'raw_values'
+        $self->{raw_values}{$_} = $hashref->{$_} for keys %{$hashref};
         $self->{decoded} = {};
         return $self->{values}{id};
     }
@@ -1231,6 +1234,7 @@ sub load_from_hash {
     foreach my $col ( grep exists $hashref->{ lc $_ }, map $_->name, $self->columns ) {
         $self->{'fetched'}{$col} = 1;
         $self->{'values'}{$col} = $hashref->{ lc $col };
+        $self->{'raw_values'}{$col} = $hashref->{ lc $col };
     }
 
     $self->{'decoded'} = {};
